@@ -5,7 +5,7 @@ cutoff.k <- function(attrs, k) {
 		stop("k too small")
 	if(k > dim(attrs)[1])
 		k = dim(attrs)[1]
-	sorted_names = rownames(attrs)[order(attrs, decreasing = TRUE)]
+	sorted_names = rownames(attrs)[do.call(order, c(attrs, decreasing = TRUE))]
 	return(sorted_names[1:k])
 }
 
@@ -18,7 +18,7 @@ cutoff.k.percent <- function(attrs, k) {
 		warning("Assumed k=1")
 		k = 1
 	}
-	sorted_names = rownames(attrs)[order(attrs, decreasing = TRUE)]
+	sorted_names = rownames(attrs)[do.call(order, c(attrs, decreasing = TRUE))]
 	return(sorted_names[1:round((k * length(sorted_names)))])
 }
 
